@@ -29,6 +29,10 @@ def path_to_symbol(file, path):
                 idx = next(items)
                 reltype, relto = "service", relto.service[idx]
                 symbol += "." + relto.name
+            elif item == 7:  # Extension
+                idx = next(items)
+                reltype, relto = "extension", relto.extension[idx]
+                symbol += "." + relto.name
             elif item == 8:  # FileOptions
                 pass
             elif item == 9:  # SourceCodeInfo
@@ -296,7 +300,7 @@ class ProtoParser:
                 if field.type_name == ".google.protobuf.Timestamp":
                     buf += "  // RFC 3339 timestamp"
                 elif field.type_name == ".google.protobuf.Duration":
-                    buf += " // Duration in seconds. Example: \"3s\" or \"3.001s\""
+                    buf += ' // Duration in seconds. Example: "3s" or "3.001s"'
             elif field.type == descriptor_pb2.FieldDescriptorProto.TYPE_INT64:
                 buf += "  // String decimal"
             elif field.type == descriptor_pb2.FieldDescriptorProto.TYPE_UINT64:
